// fonction fft2d
// Calcule la transformée de Fourier rapide pour 2 dimensions
// @param Img Image à partir de laquelle la transformée de Fourier est calculée. L'image doit être en niveau de gris, et de taille (2^n, 2^n)
// @param SensFFT Détermine le sens de la tranformation. Directe : -1; Inverse : 1.
// @return ImgTrans Résultat de la transformée de Fourier appliquée à l'image Img. 
function [ImgTrans] = fft2d(Img,SensFFT)

	// Dimensions de l'image de la taille d'une ligne de l'image
	[Height, Width] = size(Img)

    // On initialise l'image résultat
	ImgTrans = zeros(Height, Width)

	// Matrice à une ligne de la taille d'une ligne de l'image
	ImgWork = zeros(1, Width)
	
	// On traite chaque ligne de l'image
	for iRow = 1 : Height
	
	    // On recopie la ligne courante dans la matrice de travail
	    for iColumn = 1 : Width
	    
	        ImgWork(iColumn) = Img(iRow, iColumn)
	    
	    end
	    
	    // On applique la transformée de Fourier 1D sur la ligne courante
	    ImgWork = fft1d(ImgWork, SensFFT)
	
	    // On recopie la ligne de travail, résultat de la transformée, dans l'image résultat
	    for iColumn = 1 : Width
	    
	        ImgTrans(iRow, iColumn) = ImgWork(iColumn)
	    
	    end
	    
	end
	
	// Matrice à une ligne de la taille d'une colonne de l'image
	ImgWork = zeros(1, Height)
	
	// On traite chaque colonne de l'image
	for iColumn = 1 : Width
	
	    // On recopie la colonne courante dans la matrice de travail
	    for iRow = 1 : Height
	    
	        ImgWork(iRow) = ImgTrans(iRow, iColumn)
	    
	    end
	    
	    // On applique la transformée de Fourier 1D sur la colonne courante
	    ImgWork = fft1d(ImgWork, SensFFT)
	
	    // On recopie la colonne de travail, résultat de la transformée, dans l'image résultat
	    for iRow = 1 : Height
	    
	        ImgTrans(iRow, iColumn) = ImgWork(iRow)
	    
	    end
	    
	end

endfunction
